import axios from 'axios';

/**
 * Utility functions to test API connectivity
 */

// Test health endpoint
export const testHealthEndpoint = async () => {
  try {
    const response = await axios.get('/health');
    return {
      success: true,
      data: response.data,
      status: response.status
    };
  } catch (error) {
    console.error('Health endpoint error:', error);
    return {
      success: false,
      error: error.response ? error.response.data : error.message,
      status: error.response ? error.response.status : 500
    };
  }
};

// Test API authentication
export const testAuthEndpoint = async (credentials = { email: 'test@example.com', password: 'password123' }) => {
  try {
    const response = await axios.post('/api/auth/login', credentials);
    return {
      success: true,
      data: response.data,
      status: response.status
    };
  } catch (error) {
    console.error('Auth endpoint error:', error);
    return {
      success: false,
      error: error.response ? error.response.data : error.message,
      status: error.response ? error.response.status : 500
    };
  }
};

// Test API products endpoint
export const testProductsEndpoint = async (token) => {
  try {
    const config = token ? {
      headers: {
        Authorization: `Bearer ${token}`
      }
    } : {};
    
    const response = await axios.get('/api/products', config);
    return {
      success: true,
      data: response.data,
      status: response.status
    };
  } catch (error) {
    console.error('Products endpoint error:', error);
    return {
      success: false,
      error: error.response ? error.response.data : error.message,
      status: error.response ? error.response.status : 500
    };
  }
};
