#!/bin/bash

# Quick Deploy Script for InInventer
# This script uploads files and provides deployment commands

SERVER_IP="172.104.242.160"
SERVER_USER="root"

echo "======================================"
echo "InInventer Quick Deploy"
echo "======================================"
echo ""
echo "This script will:"
echo "1. Create deployment package"
echo "2. Upload files to your server"
echo "3. Provide deployment commands"
echo ""

# Create deployment package
echo "Creating deployment package..."
tar -czf ininventer-deploy.tar.gz \
  --exclude='node_modules' \
  --exclude='.git' \
  --exclude='*.log' \
  --exclude='.env' \
  --exclude='docker-compose.override.yml' \
  --exclude='ininventer-deploy.tar.gz' \
  backend/ frontend/ nginx/ \
  docker-compose.yml deploy.sh \
  start-production.sh backup.sh DEPLOYMENT.md

echo "Package created: $(ls -lh ininventer-deploy.tar.gz | awk '{print $5}')"

# Upload files
echo ""
echo "Uploading files to server..."
echo "You will be prompted for the server password..."

# Create remote directory first
ssh ${SERVER_USER}@${SERVER_IP} "mkdir -p /tmp/ininventer-deploy"

# Upload all files
scp ininventer-deploy.tar.gz deploy.sh start-production.sh backup.sh ${SERVER_USER}@${SERVER_IP}:/tmp/ininventer-deploy/

if [ $? -eq 0 ]; then
    echo ""
    echo "✅ Files uploaded successfully!"
    echo ""
    echo "======================================"
    echo "Now connect to your server and run:"
    echo "======================================"
    echo ""
    echo "ssh ${SERVER_USER}@${SERVER_IP}"
    echo ""
    echo "# Once connected, run these commands:"
    echo "cd /tmp/ininventer-deploy"
    echo "chmod +x deploy.sh"
    echo "./deploy.sh"
    echo ""
    echo "# After deploy.sh completes:"
    echo "cd /opt/ininventer"
    echo "tar -xzf /tmp/ininventer-deploy/ininventer-deploy.tar.gz"
    echo "cp /tmp/ininventer-deploy/*.sh ."
    echo "chmod +x *.sh"
    echo "./start-production.sh"
    echo ""
    echo "======================================"
else
    echo ""
    echo "❌ Upload failed. Please check your connection and try again."
fi 